@@ -32,7 +32,7 @@ public:
 
     void start() override
     {
-        const QJsonArray urls = data().value(QStringLiteral("urls")).toArray();
+        const QJsonArray urls = data().value(QLatin1String("urls")).toArray();
 
         if (urls.isEmpty()) {
             qWarning() << "no urls to share" << urls << data();
@@ -111,15 +111,11 @@ private:
     QByteArray m_resultData;
 };
 
-class Q_DECL_EXPORT PastebinPlugin : public Purpose::PluginBase
+class PastebinPlugin : public Purpose::PluginBase
 {
     Q_OBJECT
 public:
-    PastebinPlugin(QObject *p, const QVariantList &)
-        : Purpose::PluginBase(p)
-    {
-    }
-
+    using PluginBase::PluginBase;
     Purpose::Job *createJob() const override
     {
         return new PastebinJob(nullptr);
